@@ -15,11 +15,7 @@ has alien_indexer_bin_path => ( is => 'lazy', isa => Str, init_arg => undef );
 
 has sphinx_ver => ( is => 'lazy', isa => Str, init_arg => undef );
 
-our $CFG = {
-    SPHINX => {    #
-        SPHINX_VER => undef,
-    }
-};
+our $CFG = { sphinx_ver => undef, };
 
 # CLI
 around CLI => sub ( $orig, $self ) {
@@ -41,7 +37,7 @@ around CLI => sub ( $orig, $self ) {
 };
 
 sub _build_sphinx_ver ($self) {
-    return $self->cfg->{SPHINX}->{SPHINX_VER} || $ENV->dist('Pcore-Sphinx')->cfg->{SPHINX}->{SPHINX_VER};
+    return $self->cfg->{sphinx_ver} || $ENV->dist('Pcore-Sphinx')->cfg->{sphinx_ver};
 }
 
 # APP
@@ -65,72 +61,70 @@ around _build_cfg => sub ( $orig, $self ) {
     return P->hash->merge(
         $self->$orig,
         $CFG,
-        {   SPHINX => {    #
-                SERVER => {
-                    searchd => {
-                        listen                       => q[9306:mysql41],
-                        log                          => $ENV->{LOG_DIR} . $self->name . '-searchd.log',
-                        query_log                    => $ENV->{LOG_DIR} . $self->name . '-searchd-query.log',
-                        read_timeout                 => 5,
-                        client_timeout               => 300,
-                        max_children                 => 30,
-                        persistent_connections_limit => 30,
-                        pid_file                     => $self->app_dir . 'searchd.pid',
-                        max_matches                  => 1000,
-                        seamless_rotate              => 1,
-                        preopen_indexes              => 1,
-                        unlink_old                   => 1,
-                        attr_flush_period            => 0,
-                        ondisk_dict_default          => 0,
-                        mva_updates_pool             => '1M',
-                        max_packet_size              => '8M',
-                        max_filters                  => 256,
-                        max_filter_values            => 4096,
-                        listen_backlog               => 5,
-                        read_buffer                  => '256K',
-                        read_unhinted                => '32K',
-                        max_batch_queries            => '32',
-                        subtree_docs_cache           => '4M',
-                        subtree_hits_cache           => '8M',
-                        workers                      => 'threads',
-                        dist_threads                 => 4,
-                        binlog_path                  => $self->alien_data_dir,
-                        binlog_flush                 => 2,
-                        binlog_max_log_size          => '128M',
-                        thread_stack                 => '64K',
-                        expansion_limit              => 0,
-                        rt_flush_period              => 0,
-                        query_log_format             => 'sphinxql',
-                        mysql_version_string         => undef,
-                        plugin_dir                   => q[],
-                        collation_server             => 'utf8_general_ci',
-                        collation_libc_locale        => 'C',
-                        watchdog                     => 1,
-                        compat_sphinxql_magics       => 0,
-                        predicted_time_costs         => q[doc=64, hit=48, skip=2048, match=64],
-                        sphinxql_state               => $self->alien_data_dir . 'sphinxvars.sql',
-                        rt_merge_iops                => 0,
-                        rt_merge_maxiosize           => 0,
-                        ha_ping_interval             => 1000,
-                        ha_period_karma              => 60,
-                        prefork_rotation_throttle    => 0,
-                        snippets_file_prefix         => q[],
-                    },
-                    indexer => {
-                        mem_limit             => '32M',
-                        max_iops              => 0,
-                        max_iosize            => 0,
-                        max_xmlpipe2_field    => '2M',
-                        write_buffer          => '1M',
-                        max_file_field_buffer => '8M',
-                        on_file_field_error   => 'ignore_field',
-                        on_json_attr_error    => 'ignore_attr',
-                        json_autoconv_numbers => 0,
+        {   server => {
+                searchd => {
+                    listen                       => q[9306:mysql41],
+                    log                          => $ENV->{LOG_DIR} . $self->name . '-searchd.log',
+                    query_log                    => $ENV->{LOG_DIR} . $self->name . '-searchd-query.log',
+                    read_timeout                 => 5,
+                    client_timeout               => 300,
+                    max_children                 => 30,
+                    persistent_connections_limit => 30,
+                    pid_file                     => $self->app_dir . 'searchd.pid',
+                    max_matches                  => 1000,
+                    seamless_rotate              => 1,
+                    preopen_indexes              => 1,
+                    unlink_old                   => 1,
+                    attr_flush_period            => 0,
+                    ondisk_dict_default          => 0,
+                    mva_updates_pool             => '1M',
+                    max_packet_size              => '8M',
+                    max_filters                  => 256,
+                    max_filter_values            => 4096,
+                    listen_backlog               => 5,
+                    read_buffer                  => '256K',
+                    read_unhinted                => '32K',
+                    max_batch_queries            => '32',
+                    subtree_docs_cache           => '4M',
+                    subtree_hits_cache           => '8M',
+                    workers                      => 'threads',
+                    dist_threads                 => 4,
+                    binlog_path                  => $self->alien_data_dir,
+                    binlog_flush                 => 2,
+                    binlog_max_log_size          => '128M',
+                    thread_stack                 => '64K',
+                    expansion_limit              => 0,
+                    rt_flush_period              => 0,
+                    query_log_format             => 'sphinxql',
+                    mysql_version_string         => undef,
+                    plugin_dir                   => q[],
+                    collation_server             => 'utf8_general_ci',
+                    collation_libc_locale        => 'C',
+                    watchdog                     => 1,
+                    compat_sphinxql_magics       => 0,
+                    predicted_time_costs         => q[doc=64, hit=48, skip=2048, match=64],
+                    sphinxql_state               => $self->alien_data_dir . 'sphinxvars.sql',
+                    rt_merge_iops                => 0,
+                    rt_merge_maxiosize           => 0,
+                    ha_ping_interval             => 1000,
+                    ha_period_karma              => 60,
+                    prefork_rotation_throttle    => 0,
+                    snippets_file_prefix         => q[],
+                },
+                indexer => {
+                    mem_limit             => '32M',
+                    max_iops              => 0,
+                    max_iosize            => 0,
+                    max_xmlpipe2_field    => '2M',
+                    write_buffer          => '1M',
+                    max_file_field_buffer => '8M',
+                    on_file_field_error   => 'ignore_field',
+                    on_json_attr_error    => 'ignore_attr',
+                    json_autoconv_numbers => 0,
 
-                        # json_autoconv_keynames => 'lowercase',
-                        # lemmatizer_base  => $self->app_dir . q[],
-                        lemmatizer_cache => '256K',
-                    },
+                    # json_autoconv_keynames => 'lowercase',
+                    # lemmatizer_base  => $self->app_dir . q[],
+                    lemmatizer_cache => '256K',
                 },
             }
         }
@@ -139,10 +133,8 @@ around _build_cfg => sub ( $orig, $self ) {
 
 around _create_local_cfg => sub ( $orig, $self ) {
     my $local_cfg = {
-        SPHINX => {
-            SPHINX_VER => $self->cfg->{SPHINX}->{SPHINX_VER},
-            SERVER     => $self->cfg->{SPHINX}->{SERVER},
-        },
+        sphinx_ver => $self->cfg->{sphinx_ver},
+        server     => $self->cfg->{server},
     };
 
     return P->hash->merge( $self->$orig, $local_cfg );
@@ -249,20 +241,20 @@ around app_deploy => sub ( $orig, $self ) {
 sub generate_alien_cfg ($self) {
     my %cfg;
 
-    for my $section ( sort keys %{ $self->cfg->{SPHINX}->{SERVER} } ) {
-        next if !$self->cfg->{SPHINX}->{SERVER}->{$section};
+    for my $section ( sort keys %{ $self->cfg->{server} } ) {
+        next if !$self->cfg->{server}->{$section};
 
         my $cfg;
-        for my $key ( sort keys %{ $self->cfg->{SPHINX}->{SERVER}->{$section} } ) {
-            next if !defined $self->cfg->{SPHINX}->{SERVER}->{$section}->{$key};
+        for my $key ( sort keys %{ $self->cfg->{server}->{$section} } ) {
+            next if !defined $self->cfg->{server}->{$section}->{$key};
 
-            if ( ref $self->cfg->{SPHINX}->{SERVER}->{$section}->{$key} eq 'ARRAY' ) {
-                for my $val ( @{ $self->cfg->{SPHINX}->{SERVER}->{$section}->{$key} } ) {
+            if ( ref $self->cfg->{server}->{$section}->{$key} eq 'ARRAY' ) {
+                for my $val ( @{ $self->cfg->{server}->{$section}->{$key} } ) {
                     $cfg .= qq[    $key = $val\n];
                 }
             }
             else {
-                $cfg .= qq[    $key = ] . $self->cfg->{SPHINX}->{SERVER}->{$section}->{$key} . $LF;
+                $cfg .= qq[    $key = ] . $self->cfg->{server}->{$section}->{$key} . $LF;
             }
         }
 
